==> bear_2.5.4.tar.gz: bear/R/about.bear.r <==
about.bear<-function(){
cat("\n\n")
cat(" ----------------------------------------------------------------\n\n")
cat("  bear v2.5.4                                                      \n")
cat("  http://pkpd.kmu.edu.tw/bear                                      \n")  
cat("                                                                   \n")  
cat(" This package is designed to analyze average bioequivalence (ABE)  \n")  
cat(" (NCA -> ANOVA) or bioavailability (NCA only) data, with study     \n")  
cat(" design of a standard RT/TR 2-treatment, 2-sequence, and 2-period, \n")  
cat(" crossover design (2x2x2), or a replicate ABE study including      \n")  
cat(" 2-treatment, 2-sequence, with more than 2 periods (i.e., 2x2x3/   \n")  
cat(" 2x2x4/.../2x2x6), or a parallel ABE study (2x2x1). It can be      \n")  
cat(" used for single-dose or multiple-dose BE study.                   \n")
cat("                                                                   \n")
cat(" ps. bear will be crashed when it is applied to incomplete         \n")
cat(" crossover design/data.                                          \n\n")
cat(" bear was developed by Hsin-ya Lee & Yung-jin Lee.                 \n")
cat(" contact: Yung-jin Lee <mobilepk@gmail.com>                        \n")
cat(" Kaohsiung Veterans General Hospital (HY) & ptpc inc. (YJ),        \n")
cat(" Kaohsiung City, Taiwan                                          \n\n")
cat(" internet resources:                                               \n")
cat(" bear's website: http://pkpd.kmu.edu.tw/bear                       \n")
cat(" R website: http://www.r-project.org                               \n")
cat(" Users are recommended to browse Bebac Forum: R for BE/BA ->       \n") 
cat(" http://forum.bebac.at/?category=19                              \n\n")
cat(" ----------------------------------------------------------------  \n")
cat("\n Type 'go()' to run bear.\n\n")
}

==> bear_2.5.5.tar.gz: bear/R/about.bear.r <==
about.bear<-function(){
cat("\n\n")
cat(" ----------------------------------------------------------------\n\n")
cat("  bear v2.5.5                                                      \n")
cat("  http://pkpd.kmu.edu.tw/bear                                      \n")  
cat("                                                                   \n")  
cat(" This package is designed to analyze average bioequivalence (ABE)  \n")  
cat(" (NCA -> ANOVA) or bioavailability (NCA only) data, with study     \n")  
cat(" design of a standard RT/TR 2-treatment, 2-sequence, and 2-period, \n")  
cat(" crossover design (2x2x2), or a replicate ABE study including      \n")  
cat(" 2-treatment, 2-sequence, with more than 2 periods (i.e., 2x2x3/   \n")  
cat(" 2x2x4/.../2x2x6), or a parallel ABE study (2x2x1). It can be      \n")  
cat(" used for single-dose or multiple-dose BE study.                   \n")
cat("                                                                   \n")
cat(" ps. bear will be crashed when it is applied to incomplete         \n")
cat(" crossover design/data.                                          \n\n")
cat(" bear was developed by Hsin-ya Lee & Yung-jin Lee.                 \n")
cat(" contact: Yung-jin Lee <mobilepk@gmail.com>                        \n")
cat(" Kaohsiung Veterans General Hospital (HY) & ptpc inc. (YJ),        \n")
cat(" Kaohsiung City, Taiwan                                          \n\n")
cat(" internet resources:                                               \n")
cat(" bear's website: http://pkpd.kmu.edu.tw/bear                       \n")
cat(" R website: http://www.r-project.org                               \n")
cat(" Users are recommended to browse Bebac Forum: R for BE/BA ->       \n") 
cat(" http://forum.bebac.at/?category=19                              \n\n")
cat(" ----------------------------------------------------------------  \n")
cat("\n Type 'go()' to run bear or 'demo(bear.demo)' to run demo.\n\n")
}
